@@ -16,7 +16,7 @@ VIS_bands <- function(std = "ISO") {
   if (std == "ISO") {
     list(Purple(std), Blue(std), Green(std), Yellow(std), Orange(std), Red(std))
   } else {
-    warning("'std' argument value not implemented.")
+    warning("'std' argument value '", std, "' not implemented.")
     list()
   }
 }
